"""
Attendance scrapper which extract information from an attendance
page and return information in dictionary.
"""

from vasvscrapper.attendance.get_attendance import get_attendance

__all__ = ["get_attendance"]
