"""
Login Status codes representing failures and success states
in scrapping a student details.
"""

LOGIN_CREDENTIALS_INVALID = "LOGIN__CREDENTIALS_INVALID"
LOGIN_VCE_CRASHED = "LOGIN__VCE_CRASHED"
LOGIN_SUCCESS = "LOGIN__SUCCESS"
LOGIN_SCRAPPER_FAILED = "LOGIN__SCRAPPER_FAILED"
