"""
Some of the enums used in scrappers for performing
various operations in extraction.
"""

from .scrapper_enums import BranchesEnum, LoginUrlEnum, NewsPatternsEnum

__all__ = ["BranchesEnum", "NewsPatternsEnum", "LoginUrlEnum"]
