"""
Attendance status codes representing failures and success
states in scrapping attendance.
"""

ATTENDANCE_VCE_CRASHED = "ATTENDANCE__VCE_CRASHED"
ATTENDANCE_SCRAPPER_FAILED = "ATTENDANCE__SCRAPPER_FAILED"
ATTENDANCE_SUCCESS = "ATTENDANCE__SUCCESS"
