"""
News status codes representing failures and success states in scrapping news.
"""

NEWS_VCE_CRASHED = "NEWS__VCE_CRASHED"
NEWS_SCRAPPER_FAILED = "NEWS__SCRAPPER_FAILED"
NEWS_SUCCESS = "NEWS__SUCCESS"
