"""
Result status codes representing failures and success states in scrapping results.
"""

RESULT_VCE_CRASHED = "RESULT__VCE_CRASHED"
RESULT_SCRAPPER_FAILED = "RESULT__SCRAPPER_FAILED"
RESULT_SUCCESS = "RESULT__SUCCESS"
